@@ -1147,16 +1147,25 @@ class GeoArray(object):
     @staticmethod
     def _get_cmap_vmin_vmax(cmap, vmin, vmax, pmin, pmax, image2plot, nodataVal):
         from matplotlib import pyplot as plt
+
         # set color palette
-        palette = plt.get_cmap(cmap) if cmap and isinstance(cmap, str) else cmap if cmap else plt.get_cmap('gray')
+        palette = \
+            plt.get_cmap(cmap) if cmap and isinstance(cmap, str) else \
+            cmap if cmap else \
+            plt.get_cmap('gray')
         palette = copy(palette)  # allows to modify the colormap as in-place modifications are not allowed anymore
-        if nodataVal is not None and np.std(image2plot) != 0:  # do not show nodata
+
+        if nodataVal is not None and \
+           np.std(image2plot.astype(np.float)) != 0:  # do not show nodata; float is needed to avoid overflow error
+
             image2plot = np.ma.masked_equal(image2plot, nodataVal)
-            vmin_auto, vmax_auto = \
-                np.nanpercentile(image2plot.compressed(), pmin), np.nanpercentile(image2plot.compressed(), pmax)
+            vmin_auto = np.nanpercentile(image2plot.compressed(), pmin)
+            vmax_auto = np.nanpercentile(image2plot.compressed(), pmax)
             palette.set_bad('aqua', 0)
+
         else:
-            vmin_auto, vmax_auto = np.nanpercentile(image2plot, pmin), np.nanpercentile(image2plot, pmax)
+            vmin_auto = np.nanpercentile(image2plot, pmin)
+            vmax_auto = np.nanpercentile(image2plot, pmax)
 
         vmin = vmin if vmin is not None else vmin_auto
         vmax = vmax if vmax is not None else vmax_auto
@@ -1247,8 +1256,12 @@ class GeoArray(object):
                 ax = plt.gca()
 
             rows, cols = image2plot.shape[:2]
-            im = ax.imshow(image2plot, palette, interpolation=interpolation, extent=(0, cols, rows, 0),
-                           vmin=vmin, vmax=vmax, )  # compressed excludes nodata values
+            im = ax.imshow(image2plot,
+                           palette,
+                           interpolation=interpolation,
+                           extent=(0, cols, rows, 0),
+                           vmin=vmin,
+                           vmax=vmax, )  # compressed excludes nodata values
             plt.show()
 
             return im
